import numpy as np
import matplotlib.pyplot as plt
import scipy.stats

def calc_t(X, Y):
    M = len(X)
    N = len(Y)
    df = M + N - 2
    meanX = X.mean()
    meanY = Y.mean()
    ss = (((X - meanX) ** 2).sum() + ((Y - meanY) ** 2).sum()) / df
    ss_XY = ss * (M + N) / (M * N)
    t = (meanX - meanY) / (ss_XY ** 0.5)
    return t, df

mu = 170
sgm = 6
M = 10

N_Exp = 10000
t_values = []
for t in range(N_Exp):
    X = scipy.stats.norm.rvs(loc = mu, scale = sgm, size = M)
    Y = scipy.stats.norm.rvs(loc = mu, scale = sgm, size = M)
    t, df = calc_t(X, Y)
    t_values.append(t)

t_range = [v for v in np.arange(-4, 4, 0.25)]
p_values = [scipy.stats.t.pdf(t, 2 * M - 2) for t in t_range] 
plt.hist(t_values, bins = t_range, density = True)
plt.plot(t_range, p_values, linewidth = 3)
plt.plot([-5.45, -5.45], [0.0, 0.1], 'r-o', linewidth = 5, label = 't = -5.45')
plt.legend()
plt.show()

